@@ -1,21 +1,9 @@
-/* This file is part of KDevelop
-    Copyright 2006 Hamish Rodda <rodda@kde.org>
-    Copyright 2007-2008 David Nolden <david.nolden.kdevelop@art-master.de>
+/*
+    SPDX-FileCopyrightText: 2006 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 2007-2008 David Nolden <david.nolden.kdevelop@art-master.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
- */
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #ifndef KDEVPLATFORM_DECLARATION_H
 #define KDEVPLATFORM_DECLARATION_H
@@ -25,7 +13,6 @@
 
 #include "types/abstracttype.h"
 #include "duchainbase.h"
-#include "instantiationinformation.h"
 #include "identifier.h"
 #include "indexeddeclaration.h"
 
@@ -40,6 +27,7 @@ class DeclarationId;
 class Declaration;
 class IndexedTopDUContext;
 class TopDUContext;
+class IndexedInstantiationInformation;
 
 /**
  * \short Represents a single declaration in a definition-use chain.
@@ -301,8 +289,11 @@ public:
      *
      * \returns this declaration's type as \a T, or null if there is no type or it is not of type \a T.
      */
-    template <class T>
-    TypePtr<T> type() const { return TypePtr<T>::dynamicCast(abstractType()); }
+    template<class T>
+    TypePtr<T> type() const
+    {
+        return abstractType().dynamicCast<T>();
+    }
 
     /**
      * Access this declaration's type.
@@ -317,8 +308,10 @@ public:
      *
      * \param type the type to assign.
      */
-    template <class T>
-    void setType(TypePtr<T> type) { setAbstractType(AbstractType::Ptr::staticCast(type)); }
+    void setType(AbstractType::Ptr type)
+    {
+        setAbstractType(std::move(type));
+    }
 
     /**
      * Set this declaration's \a type.
